proxy — Health Dashboard

# proxy — Good

Analyzed 2026-03-23 by code2llm · Primary language: python · Python: 63, JavaScript: 22, Shell: 5

794
Functions
77
Classes
77
Files
24,560
Lines
3
Languages
3.7
Avg CC
47
Critical (CC≥10)
0
Duplicates
0
Cycles

## Language Distribution

## Largest Modules (lines)

## Most Complex Modules (functions)

## Evolution

## Top Modules (90)

Module | Path | Lines | Funcs | Classes | CC max
--- | --- | --- | --- | --- | ---
coverage_html_cb_dd2e7eb5.js | htmlcov | 735 | 65 | 0 | 21
__init__.py | src/proxym/dashboard | 660 | 39 | 10 | 13
diagnostics.py | src/proxym/api | 628 | 18 | 0 | 14
voice_fixed.jsx | TODO | 613 | 42 | 0 | 68
voice.jsx | src/proxym/dashboard/components | 521 | 46 | 0 | 70
tickets.jsx | src/proxym/dashboard/components | 471 | 20 | 0 | 20
ctl.py | src/proxym | 364 | 34 | 0 | 4
__init__.py | src/proxym/router | 352 | 14 | 1 | 9
self_server.py | src/proxym/mcp | 349 | 14 | 5 | 4
__init__.py | src/proxym/accounts | 346 | 20 | 8 | 10
__init__.py | src/proxym/cache | 333 | 10 | 3 | 9
entrypoint.sh | services/vscode | 333 | 1 | 0 | 0
__init__.py | src/proxym/providers | 331 | 4 | 3 | 8
tickets.py | src/proxym/dashboard | 329 | 20 | 9 | 17
browser_profiles.py | src/proxym/virt | 325 | 11 | 2 | 9
frontend.py | src/proxym/api | 302 | 24 | 0 | 6
_pipeline.py | src/proxym/api | 299 | 16 | 1 | 7
vms.jsx | src/proxym/dashboard/components | 275 | 30 | 0 | 32
strategy.py | src/proxym/router | 263 | 14 | 3 | 9
dsl.py | src/proxym/cli | 254 | 8 | 2 | 5

## Alerts (20)

Severity | Target | Type | Value | Limit
--- | --- | --- | --- | ---
critical | VoiceChat | cc_exceeded | 70 | 15
critical | VoiceChat | cc_exceeded | 68 | 15
critical | VoiceChat | high_fan_out | 54 | 10
critical | VoiceChat | high_fan_out | 52 | 10
critical | LogPanel | cc_exceeded | 34 | 15
critical | VMsPanel | cc_exceeded | 32 | 15
critical | DiagRooConfig | cc_exceeded | 29 | 15
critical | chat_completions | high_fan_out | 27 | 10
critical | useDashboardData | high_fan_out | 20 | 10
error | processInput | cc_exceeded | 21 | 15
error | table | cc_exceeded | 21 | 15
error | table_body_rows | cc_exceeded | 21 | 15
error | no_rows | cc_exceeded | 21 | 15
error | footer | cc_exceeded | 21 | 15
error | ratio_columns | cc_exceeded | 21 | 15

## Hotspots (10)

Function | Fan-out | Note
--- | --- | ---
VoiceChat | 54 | Orchestrates 54 calls
VoiceChat | 52 | Orchestrates 52 calls
chat_completions | 27 | OpenAI-compatible chat completions with intelligent routing. Extra headers: X
useDashboardData | 20 | Orchestrates 20 calls
run_all_tests | 19 | Run all diagnostic tests and return comprehensive status.
LogPanel | 19 | Orchestrates 19 calls
TicketsPanel | 18 | Orchestrates 18 calls
detect_firefox_profiles | 17 | Detect Firefox profiles by parsing profiles.ini.
_detect_chromium_family | 17 | Detect profiles for Chrome/Chromium from Local State file.
ollama_status | 17 | Check Ollama connectivity and list available local models.

## Refactoring Priorities (15)

# | Action | Impact | Effort
--- | --- | --- | ---
1 | Split VoiceChat (CC=68 → target CC<10) | high | low
2 | Split LogPanel (CC=34 → target CC<10) | high | low
3 | Split VMsPanel (CC=32 → target CC<10) | high | low
4 | Split VoiceChat (CC=70 → target CC<10) | high | low
5 | Split DiagRooConfig (CC=29 → target CC<10) | high | low
6 | Split god module src/proxym/dashboard/components/voice.jsx (521L, 0 classes) | high | high
7 | Split god module TODO/voice_fixed.jsx (613L, 0 classes) | high | high
8 | Split god module htmlcov/coverage_html_cb_dd2e7eb5.js (735L, 0 classes) | high | high
9 | Split god module src/proxym/api/diagnostics.py (628L, 0 classes) | high | high
10 | Split god module src/proxym/dashboard/__init__.py (660L, 10 classes) | high | high
11 | Split TicketManager.list_tickets (CC=17 → target CC<10) | medium | low
12 | Split chat_completions (CC=17 → target CC<10) | medium | low
13 | Split processInput (CC=21 → target CC<10) | medium | low
14 | Split ctrl (CC=15 → target CC<10) | medium | low
15 | Split formatToolResult (CC=19 → target CC<10) | medium | low